Welcome to Shape4D’s documentation! — Shape4D 0.08 documentation

# Welcome to Shape4D’s documentation!

## 这里是Shape4D图形库的中文帮助文件，制作Shape4D的初衷是为了计算太阳照射下建筑形成的阴影面积，目前还处于建设阶段

当前版本的Shape4D可以实现大多数基本图形关系的运算

当前版本0.08

- 关于 Shape4D
  - Shape4D的功能
- 程序包的安装
  - 准备工作
  - 安装包
- 使用之前
  - 模块导入：Shape4D

- 点，线，多边形的创建
  - 点
  - 线，面
  - 线段
  - 多边形
- 点与线面的关系
  - 点和线关系
  - 点和面关系
- 线与线，面，多边形的关系
  - 1.线与线
  - 2.线与面
  - 2.线与多边形
- 设定计算精度

# 备注

有其它问题欢迎进行反馈

# Indices and tables

- Index

- Module Index

- Search Page